#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@File  : hello.py
@Author: HappyLay
@Date  : 2020/10/16 16:22
@Desc  : 安徽理工大学
"""
__author__ = 'HappyLay'

import click
import time
import os

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])


@click.group(context_settings=CONTEXT_SETTINGS)
@click.version_option(version='1.0.0')
def cli():
    pass


@cli.command()
@click.option('--count', default=1, help='问候的次数')
@click.option('--name', prompt='你的名字', help='问候的名字')
@click.option('--t', default='y', required=True,
              type=click.Choice(['y', 'n']),
              prompt='打印当前时间戳',
              help='打印时间戳')
def hello(count, name, t):
    """
    简单的问候名字次数程序
    :param count: 问候的次数
    :param name: 问候的名字
    :param t: 是否打印当前时间戳
    :return: None
    """
    for x in range(count):
        click.echo('你好 %s!' % name)
    if t == 'y':
        print(time.time())

    return None


@cli.command(context_settings=CONTEXT_SETTINGS)
@click.argument('a', type=int, required=True)
@click.argument('b', type=int, required=True)
def add(a, b):
    """
    两数相加
    :param a: 加数
    :param b: 被加数
    :return: 结果
    """
    click.echo(click.style('%s+%s=' % (a, b), fg='green', bold=True))
    print(a + b)
    return a + b


@cli.command()
def read():
    """
    读取静态资源
    :return:
    """
    # 获取当前文件路径
    path = os.path.dirname(os.path.abspath(__file__))
    # 获取上级目录
    path = os.path.dirname(path)

    js_path = path + '/static/hi.js'

    resp = os.popen('cat ' + js_path)
    print(resp.read())
    resp.close()


if __name__ == '__main__':
    cli()



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@File  : t1.py
@Author: HappyLay
@Date  : 2020/10/17 00:21
@Desc  : 安徽理工大学
"""
__author__ = 'HappyLay'

from math import sqrt, pow
from decimal import Decimal


# x2 - 10x +16 = 0

# 参数
# a, b, c = 1, -10, 16

def equation(a, b, c):
    """
    计算二元一次方程
    :param a: 一次项系数
    :param b: 二次型系数
    :param c: 常数
    :return:
    """
    x1 = None
    x2 = None
    # 通项公式
    dt = pow(b, 2) - 4 * a * c

    # 判断解的情况
    if dt == 0:
        x1 = x2 = (-b + sqrt(dt)) / (2 * a)
        print('相同解：', x1)
    elif dt > 0:
        x1 = (-b + sqrt(dt)) / (2 * a)
        x2 = (-b - sqrt(dt)) / (2 * a)
        print('不同解：', x1, x2)
    else:
        print('无解')

    return x1, x2


if __name__ == '__main__':
    # 精度丢失
    print(0.3 - 0.1)

    print(Decimal('0.3') - Decimal('0.1'))

    x3 = x4 = 1
    print(x3, x4)

    x1, x2 = equation(1, 4, -12)
    print(x1, x2)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@File  : setup.py
@Author: HappyLay
@Date  : 2020/10/15 13:32
@Desc  : 安徽理工大学
"""
__author__ = 'HappyLay'

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="hi2020",  # 模块名称
    version="1.0.4",  # 当前版本
    author="happylay",  # 作者
    keywords='hi2020 cli',  # 关键词
    license="Apache Software License",  # 许可证
    # author_email="",  # 作者邮箱
    description="一个hi问候包",  # 模块介绍
    long_description=long_description,  # 模块详细介绍
    long_description_content_type="text/markdown",  # 模块详细介绍格式
    # url="",  # 模块github地址
    packages=find_packages('src'),  # 自动找到项目中导入的模块
    package_dir={'': 'src'},
    include_package_data=True,
    package_data={
        'config': ['*.conf', '*.example'],
        'docs': [],
        'tests': []
    },
    # 模块相关的元数据（更多描述信息）https://pypi.org/classifiers/
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    # 命令行工具
    entry_points={
        'console_scripts': [
            'hi = hi2020.bin.cli:cli'  # 命令名称=包.包:函数
        ],
    },
    # 依赖模块
    install_requires=[
        'click',
    ],
    python_requires='>=3'

)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@File  : helloworld.py
@Author: HappyLay
@Date  : 2020/10/15 13:33
@Desc  : 安徽理工大学
"""
__author__ = 'HappyLay'


def hi():
    """
    向世界的第一个问候(*^▽^*)
    :return: None
    """
    print("hello world , 2020🇨🇳加油，世界ヾ(◍°∇°◍)ﾉﾞ。")
    return None
